@@ -367,7 +367,8 @@ class Hooks:
                 default = self._resolve_default(fn, p, p["default"])
                 default = self._maybe_add_default_arg_cast(p, default)
                 p["default"] = default
-                p["x_pyarg"] += "=" + p["default"]
+                if default:
+                    p["x_pyarg"] += "=" + p["default"]
 
             ptype = "in"
 
@@ -490,7 +491,12 @@ class Hooks:
         if x_temps:
             for out in reversed(x_temps):
                 odef = out.get("default", "0")
-                x_lambda_pre.insert(0, f"{out['x_type']} {out['name']} = {odef}")
+                if not odef:
+                    x_lambda_pre.insert(0, f"{out['x_type']} {out['name']}")
+                elif odef.startswith("{"):
+                    x_lambda_pre.insert(0, f"{out['x_type']} {out['name']}{odef}")
+                else:
+                    x_lambda_pre.insert(0, f"{out['x_type']} {out['name']} = {odef}")
 
         # Rename functions
         if data.rename:
