@@ -791,10 +791,12 @@ template <typename base, typename deleter> struct is_holder_type<base, std::uniq
     std::true_type {};
 
 template <typename T> struct handle_type_name { static constexpr auto name = const_name<T>(); };
+template <> struct handle_type_name<bool_> { static constexpr auto name = const_name("bool"); };
 template <> struct handle_type_name<bytes> { static constexpr auto name = const_name(PYBIND11_BYTES_NAME); };
 template <> struct handle_type_name<int_> { static constexpr auto name = const_name("int"); };
 template <> struct handle_type_name<iterable> { static constexpr auto name = const_name("Iterable"); };
 template <> struct handle_type_name<iterator> { static constexpr auto name = const_name("Iterator"); };
+template <> struct handle_type_name<float_> { static constexpr auto name = const_name("float"); };
 template <> struct handle_type_name<none> { static constexpr auto name = const_name("None"); };
 template <> struct handle_type_name<args> { static constexpr auto name = const_name("*args"); };
 template <> struct handle_type_name<kwargs> { static constexpr auto name = const_name("**kwargs"); };
